@@ -2677,7 +2677,7 @@ bool inc_stat(int stat)
 		/* Gain one (sometimes two) points */
 		if (value < 18)
 		{
-			gain = ((randint0(100) < 75) ? 1 : 2);
+			gain = ((randint0(100) < 75) ? 1 : ((value < 17) ? 2 : 11));
 			value += gain;
 		}
 
